@@ -31,6 +31,7 @@ from aiohomekit.exceptions import (
     HttpErrorResponse,
     TimeoutError,
 )
+import aiohomekit.hkjson as hkjson
 from aiohomekit.http import HttpContentTypes
 from aiohomekit.http.response import HttpResponse
 from aiohomekit.protocol import get_session_keys
@@ -315,7 +316,7 @@ class HomeKitConnection:
     async def get_json(self, target):
         response = await self.get(target)
         body = response.body.decode("utf-8")
-        return json.loads(body)
+        return hkjson.loads(body)
 
     async def put(self, target, body, content_type=HttpContentTypes.JSON):
         """
@@ -348,7 +349,7 @@ class HomeKitConnection:
             )
 
         try:
-            parsed = json.loads(decoded)
+            parsed = hkjson.loads(decoded)
         except json.JSONDecodeError:
             self.transport.close()
             raise AccessoryDisconnectedError(
@@ -387,7 +388,7 @@ class HomeKitConnection:
             return {}
 
         try:
-            parsed = json.loads(decoded)
+            parsed = hkjson.loads(decoded)
         except json.JSONDecodeError:
             self.transport.close()
             raise AccessoryDisconnectedError(
@@ -576,7 +577,7 @@ class HomeKitConnection:
             return
 
         try:
-            parsed = json.loads(decoded)
+            parsed = hkjson.loads(decoded)
         except json.JSONDecodeError:
             return
 
